lcvtoolbox.vision.encoding.rle.cvat\_api.CvatApiRLE
===================================================

.. currentmodule:: lcvtoolbox.vision.encoding.rle.cvat_api

.. autoclass:: CvatApiRLE
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiRLE.__init__
      ~CvatApiRLE.array_to_rle
      ~CvatApiRLE.binary_mask_to_bbox
      ~CvatApiRLE.decode
      ~CvatApiRLE.decode_cvat_rle
      ~CvatApiRLE.encode
      ~CvatApiRLE.from_array
      ~CvatApiRLE.mask_to_rle
      ~CvatApiRLE.rle_to_array
      ~CvatApiRLE.to_cvat_mask
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiRLE.BBOX_LENGTH
      ~CvatApiRLE.bbox
   
   